@@ -468,6 +468,24 @@ class SubmitClient:
          os.rename(tmpParameterCombinationsPath,self.clientData['jobScanPath'])
 
 
+   @staticmethod
+   def __which(program):
+      def isExe(fpath):
+         return(os.path.isfile(fpath) and os.access(fpath,os.X_OK))
+
+      fpath,fname = os.path.split(program)
+      if fpath:
+         if isExe(program):
+            return(program)
+      else:
+         for path in os.environ["PATH"].split(os.pathsep):
+            exePath = os.path.join(path,program)
+            if isExe(exePath):
+               return(exePath)
+
+      return(None)
+
+
    def startLocalParametric(self):
       exitCode = 0
       useEnvironment = ""
@@ -536,6 +554,7 @@ class SubmitClient:
       self.commandParser.writeParameterCombinations(self.clientData['jobScanPath'])
 
       inputError = False
+      executableExistsError = False
       nInstanceIdDigits = max(2,int(math.log10(self.commandParser.getParameterCombinationCount())+1))
       instance = 0
       for substitutions in self.commandParser.getNextParameterCombinationFromCSV(self.clientData['jobScanPath']):
@@ -607,7 +626,21 @@ class SubmitClient:
          inputFiles = substitutedInputFiles
 
          remoteArgs = []
-         for arg in enteredCommandArguments:
+
+         executable = self.__which(enteredCommandArguments[0])
+         if executable:
+            executable = os.path.realpath(executable)
+            remoteArgs.append(executable)
+         else:
+            if not executableExistsError:
+               sys.stderr.write("Specified command %s is not in your PATH\n" % (enteredCommandArguments[0]))
+            inputError = True
+            # allow completion of input checks
+            remoteArgs.append(enteredCommandArguments[0])
+            executable = enteredCommandArguments[0]
+            executableExistsError = True
+
+         for arg in enteredCommandArguments[1:]:
             if arg.startswith('-'):
                remoteArgs.append(arg)
             else:
@@ -629,10 +662,8 @@ class SubmitClient:
                      remoteArgs.append(arg)
 
          remoteCommand = " ".join(remoteArgs)
-
-         executable = os.path.abspath(remoteArgs[0])
-         arguments  = " ".join(remoteArgs[1:])
-         arguments  = arguments.strip()
+         arguments     = " ".join(remoteArgs[1:])
+         arguments     = arguments.strip()
 
          timeHistoryLogs = {}
          timeHistoryLogs['timestampTransferred'] = "%s.%s_%s" % (TIMESTAMPTRANSFERRED,localJobId,instanceId)
@@ -716,8 +747,10 @@ class SubmitClient:
          if not sys.stdin in self.clientData['inputObjects']:
             self.clientData['inputObjects'][sys.stdin] = '#STDIN#'
 
-         self.jobScanner = JobScanner(self.clientData['jobScanPath'])
-         self.jobScanner.start()
+         self.clientData['isClientTTY'] = sys.stdin.isatty() and sys.stdout.isatty()
+         if self.clientData['isClientTTY']:
+            self.jobScanner = JobScanner(self.clientData['jobScanPath'])
+            self.jobScanner.start()
 
 
    def startLocalExecute(self):
@@ -786,6 +819,9 @@ class SubmitClient:
             self.serverConnection.postServerMessage('localMetrics %d %d %f %f\n' % (instance,exitCode,cpuTime,elapsedRunTime))
             del jobStatistic
 
+         if not self.clientData['isClientTTY']:
+            sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % (self.clientData['jobPath']))
+
 
    def finishLocal(self):
       if self.clientData['isParametric']:
@@ -1137,7 +1173,7 @@ class SubmitClient:
                      resultsPath = self.clientData['jobPath']
                   else:
                      resultsPath = os.path.join(self.clientData['jobPath'],"%08d" % (self.serverData['jobId']))
-                  sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % resultsPath)
+                  sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % (resultsPath))
             elif self.clientData['readyToExit']:
                self.exit()
 
@@ -1154,7 +1190,7 @@ class SubmitClient:
                      resultsPath = self.clientData['jobPath']
                   else:
                      resultsPath = os.path.join(self.clientData['jobPath'],"%08d" % (self.serverData['jobId']))
-                  sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % resultsPath)
+                  sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % (resultsPath))
                   os.kill(os.getpid(),signal.SIGINT)
             else:
                self.readFile(readyReader)
